Learn R Programming

fmri (version 1.0)

fmri.design: Linear Model for FMRI Data

Description

Return a design matrix for a linear model with given stimuli and possible polynomial drift terms.

Usage

fmri.design(hrf, order = 2)

Arguments

hrf
matrix containing expected BOLD repsonse(s) for the linear model as columns
order
order of the polynomial drift terms

Value

  • design matrix of the linear model

Details

The stimuli given in hrf are used as first columns in the design matrix.

The order of the polynomial drift terms is given by order, which defaults to 2.

The polynomials are defined orthogonal to the stimuli given in hrf.

See Also

fmri.stimulus, fmri.lm

Examples

Run this code
# Example 1
  hrf <- fmri.stimulus(107, c(18, 48, 78), 15, 2)
  z <- fmri.design(hrf,2)
  par(mfrow=c(2,2))
  for (i in 1:4) plot(z[,i],type="l")

Run the code above in your browser using DataLab