logical. if TRUE the mean is substracted from the resulting vector
a1
parameter of the hemodynamic response function (see details)
a2
parameter of the hemodynamic response function (see details)
b1
parameter of the hemodynamic response function (see details)
b2
parameter of the hemodynamic response function (see details)
cc
parameter of the hemodynamic response function (see details)
Value
Vector with dimension c(scans,1).
Details
The functions calculates the expected BOLD response for the task
indicator function given by the argument as a convolution with the
hemodynamic response function. The latter is modelled by the difference
between two gamma functions as given in the reference (with the defaults
for a1, a2, b1, b2, cc given therein):
$$\left(\frac{t}{d_1}\right)^{a_1} \exp \left(-\frac{t-d_1}{b_1}\right)
- c \left(\frac{t}{d_2}\right)^{a_2} \exp
\left(-\frac{t-d_2}{b_2}\right)$$
The parameters of this function can be changed through the arguments
a1, a2, b1, b2, cc.
The dimension of the function value is set to c(scans,1).
If mean is TRUE (default) the resulting vector is
corrected to have zero mean.
References
Worsley, K.J., Liao, C., Aston, J., Petre, V., Duncan,
G.H., Morales, F., Evans, A.C. (2002). A general statistical analysis
for fMRI data. NeuroImage, 15:1-15.