Learn R Programming

fmri (version 1.0)

read.NIFTI: I/O Functions

Description

Read fMRI data from NIFTI file(s).

Usage

read.NIFTI(filename)

Arguments

filename
name of the NIFTI file

Value

  • Object of class "fmridata" with the following list entries:
  • tttfour dimensional data cube, the first three dimensions are voxel dimensions, the fourth dimension denotes the time
  • headerheader information of the data
  • formatdata source. string "NIFTI"
  • deltavoxel size in mm
  • originposition of the datacube origin
  • orientdata orientation code
  • dimdimension of the datacube
  • weightsweights vector coding the relative voxel sizes in x, y, z-direction
  • maskhead mask

Details

This function reads fMRI data files in NIFTI format.

The filename can be given with our without extension. If extension is not included, the function searches for the ".nii" file and then for the "hdr/img" pair.

See Also

read.ANALYZE, read.AFNI

Examples

Run this code
analyze <- read.NIFIT("niftifile.nii")

Run the code above in your browser using DataLab