Learn R Programming

fmri (version 1.0)

summary.fmridata: I/O functions

Description

'summary' method for class '"fmridata"'.

Usage

summary.fmridata(object, ...)

Arguments

object
an object of class fmridata, usually, a result of a call to fmri.lm, fmri.smooth, fmri.pvalue, read.AFNI, or read.ANALYZE.
...
further arguments passed to or from other methods.

Value

  • A list with the following elements:
  • dimdata dimension
  • deltavoxel dimension, if available
  • valuesvalue range
  • zdesign matrix

Details

The method tries to print information on data, like data dimension, voxel size, value range.

See Also

print.fmridata

Examples

Run this code
summary(data)

Run the code above in your browser using DataLab