fmri.pvalue(spm, mode="basic", delta=NULL)fmrispm objectplot for thresholding.spm, we simply use a t-statistic
and define p-values according to random field theory for the resulting gaussian
field (sufficiently large number of df - see ref.). If spm is a
vector of length larger then one for each voxel, a chisq field is calculated and evaluated (see
Worsley and Taylor (2006)). If delta is given, a cone statistics is
used. The parameter mode allows for different kinds of p-value
calculation. "basic" corresponds to a global definition of the
resel counts based on the amount of smoothness achieved by an equivalent
Gaussian filter. The propagation condition ensures, that under the
hypothesis
$$\hat{\Theta} = 0$$
adaptive smoothing perform like a
non adaptive filter with the same kernel function which justifies this
approach. "local"
corresponds to a more conservative setting, where the p-value is
derived from the estimated local resel counts that has been achieved by
adaptive smoothing. In contrast to "basic", "global" takes a global
median to adjust for the randomness of the weighting scheme generated
by adaptive smoothing. "global" and "local" are more conservative than
basic, that is, they generate sligthly larger p-values.
fmri.smooth, plot.fmridata