Learn R Programming

fmri (version 1.0)

fmri.smooth: Smoothing Statistical Parametric Maps

Description

Perform the adaptive weights smoothing procedure

Usage

fmri.smooth(spm, hmax = 4, adaptive=TRUE,
            lkern="Triangle", skern="Triangle", na.rm=FALSE)

Arguments

spm
object of class fmrispm
hmax
maximum bandwidth to smooth
adaptive
logical. TRUE (default) for adaptive smoothing
lkern
lkern specifies the location kernel. Defaults to "Triangle", other choices are "Gaussian", "Quadratic", "Cubic" and "Uniform". Note that the location kernel is applied to (x-x_j)^2/h^2, i.e. the use of "Triangle" corr
skern
skern specifies the kernel for the statistical penalty. Defaults to "Triangle", the alternative is "Exp". lkern="Triangle" allows for much faster computation (saves up to 50%).
na.rm
na.rm specifies how NA's in the SPM are handled. NA's may occur in voxel where the time series information did not allow for estimating parameters and their variances or where the time series information where constant over time. A high

Value

  • object with class attributes "fmrispm" and "fmridata"
  • cbetasmoothed parameter estimate
  • varvariance of the parameter
  • hmaxmaximum bandwidth used
  • rxyzsmoothness in resel space. all directions
  • rxyz0smoothness in resel space as would be achieved by a Gaussian filter with the same bandwidth. all directions
  • scorrspatial correlation of original data
  • weightsratio of voxel dimensions
  • vwghtsratio of estimated variances for the stimuli given by vvector
  • hrfExpected BOLD response for the specified effect

Details

This function performs the smoothing on the Statistical Parametric Map spm.

hmax is the (maximal) bandwidth used in the last iteration. Choose adaptive as FALSE for non adaptive smoothing. lkern can be used for specifying the localization kernel. For comparison with non adaptive methods use "Gaussian" (hmax given in FWHM), for better adaptation use "Triangle" (default, hmax given in voxel). skern can be used for specifying the kernel for the statistical penalty.

The function handles zero variances by assigning a large value (1e20) to these variances.

References

Tabelow, K., Polzehl, J., Voss, H.U., and Spokoiny, V. (2005). Analysing {fMRI} experiments with structure adaptive smoothing procedures, NeuroImage, accepted (2006).

Polzehl, J. and Spokoiny, V. (2006). Propagation-Separation Approach for Local Likelihood Estimation, Probab. Theory Relat. Fields 135, 335-362.

Examples

Run this code
fmri.smooth(spm, hmax = 4, lkern = "Gaussian")

Run the code above in your browser using DataLab