Object of class "fmridata" with the following list entries:
tttfour dimensional data cube, the first three dimensions are voxel
dimensions, the fourth dimension denotes the time
headerheader information of the data
formatdata source. string "NIFTI"
deltavoxel size in mm
originposition of the datacube origin
orientdata orientation code
dimdimension of the datacube
weightsweights vector coding the relative voxel sizes in x,
y, z-direction
maskhead mask
Details
This function reads fMRI data files in NIFTI format.
The filename can be given with our without extension. If extension is
not included, the function searches for the ".nii" file and then for
the "hdr/img" pair.